Title: [102072] trunk/Tools
Revision
102072
Author
[email protected]
Date
2011-12-05 17:08:04 -0800 (Mon, 05 Dec 2011)

Log Message

Up the "expected ram for each DRT instance" to 400MB instead of 300MB
in hopes of making the Snow Leopard bot stop timing out.

Unreviewed.

* Scripts/webkitpy/layout_tests/port/base.py:
(Port.default_child_processes):
* Scripts/webkitpy/layout_tests/port/base_unittest.py:
(PortTest.test_default_child_processes):

Modified Paths

Diff

Modified: trunk/Tools/ChangeLog (102071 => 102072)


--- trunk/Tools/ChangeLog	2011-12-06 01:03:53 UTC (rev 102071)
+++ trunk/Tools/ChangeLog	2011-12-06 01:08:04 UTC (rev 102072)
@@ -1,5 +1,17 @@
 2011-12-05  Eric Seidel  <[email protected]>
 
+        Up the "expected ram for each DRT instance" to 400MB instead of 300MB
+        in hopes of making the Snow Leopard bot stop timing out.
+
+        Unreviewed.
+
+        * Scripts/webkitpy/layout_tests/port/base.py:
+        (Port.default_child_processes):
+        * Scripts/webkitpy/layout_tests/port/base_unittest.py:
+        (PortTest.test_default_child_processes):
+
+2011-12-05  Eric Seidel  <[email protected]>
+
         NRWT creates too many workers on RAM-limited machines
         https://bugs.webkit.org/show_bug.cgi?id=73847
 

Modified: trunk/Tools/Scripts/webkitpy/layout_tests/port/base.py (102071 => 102072)


--- trunk/Tools/Scripts/webkitpy/layout_tests/port/base_unittest.py	2011-12-06 01:03:53 UTC (rev 102071)
+++ trunk/Tools/Scripts/webkitpy/layout_tests/port/base_unittest.py	2011-12-06 01:08:04 UTC (rev 102072)
@@ -56,7 +56,7 @@
     def test_default_child_processes(self):
         port = self.make_port()
         self.assertEqual(port.default_child_processes(), 2)
-        bytes_for_drt = 300 * 1024 * 1024
+        bytes_for_drt = 400 * 1024 * 1024
 
         port.host.platform.total_bytes_memory = lambda: bytes_for_drt
         expected_stdout = "This machine could support 2 child processes, but only has enough memory for 1.\n"
_______________________________________________
webkit-changes mailing list
[email protected]
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes

Reply via email to
--- trunk/Tools/Scripts/webkitpy/layout_tests/port/base.py	2011-12-06 01:03:53 UTC (rev 102071)
+++ trunk/Tools/Scripts/webkitpy/layout_tests/port/base.py	2011-12-06 01:08:04 UTC (rev 102072)
@@ -168,7 +168,7 @@
         # Make sure we have enough ram to support that many instances:
         total_memory = self.host.platform.total_bytes_memory()
         if total_memory:
-            bytes_per_drt = 300 * 1024 * 1024  # Assume each DRT needs 300MB to run.
+            bytes_per_drt = 400 * 1024 * 1024  # Assume each DRT needs 400MB to run.
             supportable_instances = total_memory / bytes_per_drt
             if supportable_instances < cpu_count:
                 # FIXME: The Printer isn't initialized when this is called, so using _log would just show an unitialized logger error.

Modified: trunk/Tools/Scripts/webkitpy/layout_tests/port/base_unittest.py (102071 => 102072)

